@@ -2,13 +2,10 @@
 # -----------------------------------------------------------------------------
 # xmlconfig.py - xml config to python converter
 # -----------------------------------------------------------------------------
-# $Id: xmlconfig.py 2719 2007-06-23 20:46:12Z tack $
+# $Id: xmlconfig.py 4070 2009-05-25 15:32:31Z tack $
 #
 # -----------------------------------------------------------------------------
-# Copyright (C) 2006 Dirk Meyer, Jason Tackaberry
-#
-# First Edition: Dirk Meyer <dmeyer@tzi.de>
-# Maintainer:    Dirk Meyer <dmeyer@tzi.de>
+# Copyright 2006-2009 Dirk Meyer, Jason Tackaberry
 #
 # Please see the file AUTHORS for a complete list of authors.
 #
@@ -31,7 +28,6 @@
 __all__ = [ 'convert' ]
 
 # python imports
-import sys
 import pprint
 
 # use minidom because it is part of the python distribution.
@@ -85,7 +81,7 @@ class Parser(object):
                 schema.append(child)
         return schema
 
-    
+
     def parse(self, node, fd, deep=''):
         fd.write('%s(' % node.nodeName.capitalize())
         first = True
@@ -103,7 +99,7 @@ class Parser(object):
             else:
                 fd.write('desc=\'%s\'' % desc)
         getattr(self, '_parse_%s' % node.nodeName.lower())(node, fd, deep, first)
-    
+
 
     def _parse_var(self, node, fd, deep, first):
         default = node.getAttribute('default')
@@ -127,10 +123,10 @@ class Parser(object):
             break
         fd.write(')')
 
-    
+
     def _parse_config(self, node, fd, deep, first):
         self._parse_group(node, fd, deep, first)
-        
+
 
     def _parse_group(self, node, fd, deep, first):
         if not first:
@@ -145,8 +141,8 @@ class Parser(object):
         if node.nodeName == 'config':
             fd.write(", module='%s.config'" % self._package)
         fd.write(')')
-    
-    
+
+
     def _parse_list(self, node, fd, deep, first):
         if not first:
             fd.write(', ')
@@ -171,23 +167,23 @@ class Parser(object):
             defaults[var.getAttribute('key')] = value
         if defaults:
             fd.write(', defaults=%s' % pprint.pformat(defaults).strip())
-            
+
         fd.write(')')
 
 
     def _parse_dict(self, node, fd, deep, first):
         self._parse_list(node, fd, deep, first)
-        
+
 
 
 def convert(xml, python, package):
     tree = minidom.parse(xml).firstChild
     if tree.nodeName != 'config':
         raise RuntimeError('%s is no valid cxml file' % xml)
-    
+
     # out = sys.__stdout__
     out = open(python, 'w')
-    
+
     out.write('# auto generated file\n\n')
     out.write('from kaa.config import Var, Group, Dict, List, Config\n\n')
     out.write('config = ')
