@@ -2,13 +2,10 @@
 # -----------------------------------------------------------------------------
 # inotify/__init__.py - Inotify interface
 # -----------------------------------------------------------------------------
-# $Id: __init__.py 3069 2008-02-13 18:43:13Z dmeyer $
+# $Id: __init__.py 4070 2009-05-25 15:32:31Z tack $
 #
 # -----------------------------------------------------------------------------
-# Copyright (C) 2006 Jason Tackaberry, Dirk Meyer
-#
-# First Edition: Jason Tackaberry <tack@urandom.ca>
-# Maintainer:    Jason Tackaberry <tack@urandom.ca>
+# Copyright 2006-2009 Jason Tackaberry, Dirk Meyer
 #
 # Please see the file AUTHORS for a complete list of authors.
 #
@@ -34,6 +31,8 @@ import struct
 import logging
 import fcntl
 import select
+import errno
+import socket
 
 # kaa imports
 import kaa
@@ -187,17 +186,17 @@ class INotify(object):
 
         self._read_buffer += data
 
-        event_len = struct.calcsize('LLLL')
+        event_len = struct.calcsize('IIII')
         while True:
             if len(self._read_buffer) < event_len:
                 if self._move_state:
-                    # We received a MOVED_FROM event with no matching 
+                    # We received a MOVED_FROM event with no matching
                     # MOVED_TO.  If we don't get a matching MOVED_TO in 0.1
                     # seconds, emit the MOVED_FROM event.
                     self._moved_timer.start(0.1)
                 break
 
-            wd, mask, cookie, size = struct.unpack("LLLL", self._read_buffer[0:event_len])
+            wd, mask, cookie, size = struct.unpack("IIII", self._read_buffer[0:event_len])
             if size:
                 name = self._read_buffer[event_len:event_len+size].rstrip('\0')
             else:
@@ -218,7 +217,7 @@ class INotify(object):
 
             if self._move_state:
                 # Last event was a MOVED_FROM. So if this is a MOVED_TO and the
-                # cookie matches, emit once specifying both paths. If not, 
+                # cookie matches, emit once specifying both paths. If not,
                 # emit two signals.
                 if mask & INotify.MOVED_TO and cookie == self._move_state[2]:
                     # Great, they match. Fire a MOVE signal with both paths.
@@ -232,7 +231,7 @@ class INotify(object):
                     self._moved_timer.stop()
                     continue
 
-                # No match, fire the earlier MOVED_FROM signal now 
+                # No match, fire the earlier MOVED_FROM signal now
                 # with no target.
                 self._emit_last_move()
 
