@@ -1,13 +1,16 @@
 import time
 import os
 import sys
+import gc
 import kaa
 import kaa.rpc
 
+sig = kaa.Signals('one', 'two', 'three')
+
 class Server(object):
     def __init__(self):
         self.s = kaa.rpc.Server('test')
-        self.s.connect(self)
+        self.s.register(self)
 
     @kaa.rpc.expose('test1')
     def test1(self, x):
@@ -40,7 +43,7 @@ class Server(object):
 
     @kaa.rpc.expose('test6')
     def test6(self, x):
-        raise ValueError
+        raise ValueError('This exception is expected')
 
     @kaa.rpc.expose('shutdown')
     def shutdown(self):
@@ -94,7 +97,7 @@ def foo():
             print f, 'needs more time'
             yield x                     # waiting...
             # subyield is now done
-            x = x.get_result()
+            x = x.result
         else:
             # this should happen for fast
             print f, 'was a yield function but did not stop'
@@ -110,39 +113,39 @@ def foo():
     callback = kaa.InProgressCallback()
     async(callback, 7, 8)
     yield callback
-    print callback.get_result()                # (7, 8)
+    print callback.result                # (7, 8)
 
     callback = kaa.InProgressCallback()
     async(callback)
     yield callback
-    print callback.get_result()                # None
+    print callback.result                # None
 
     callback = kaa.InProgressCallback()
     async(callback, 9)
     yield callback
-    print callback.get_result()                # 9
+    print callback.result                # 9
 
     callback = kaa.InProgressCallback()
     async(callback, foo=10)
     yield callback
-    print callback.get_result()                # 10
+    print callback.result                # 10
 
     callback = kaa.InProgressCallback()
     async(callback, foo=11, bar=12)
     yield callback
-    print callback.get_result()                # {'foo': 11, 'bar': 12}
+    print callback.result                # {'foo': 11, 'bar': 12}
 
     x = thread(13)
     # this is also an InProgress object
     yield x
-    print x.get_result()                           # 13
+    print x.result                           # 13
 
     x = thread('crash')
     try:
         # the thread raised an exception, so x() will
         # raise it here
         yield x
-        print x.get_result()
+        print x.result
         print 'crash test failed'
     except:
         print 'crash test ok'
@@ -150,41 +153,34 @@ def foo():
     print 14
 
     print 'connect to server'
-    while 1:
-        try:
-            c = kaa.rpc.Client('test')
-            break
-        except Exception, e:
-            time.sleep(0.1)
-            print e
-            pass
+    c = kaa.rpc.connect('test')
     print 'server tests'
 
     # normal rpc
     result = c.rpc('test1', 15)
     yield result
-    print result.get_result()
+    print result.result
 
     # rpc in a thread
     result = c.rpc('test2', 16)
     yield result
-    print result.get_result()
+    print result.result
     
     # rpc with yield direct
     result = c.rpc('test3', 17)
     yield result
-    print result.get_result()
+    print result.result
     
     # rpc with yield indirect
     result = c.rpc('test4', 18)
     yield result
-    print result.get_result()
+    print result.result
     
     # rpc with yield error
     result = c.rpc('crash')
     try:
         yield result
-        result.get_result()
+        result.result
         print 'bad rpc test failed'
     except:
         print 'bad rpc test ok'
@@ -193,7 +189,7 @@ def foo():
     result = c.rpc('test6', 18)
     try:
         yield result
-        result.get_result()
+        result.result
         print 'remote rpc exception test failed'
     except ValueError, e:
         print 'remote rpc exception test ok'
@@ -203,8 +199,35 @@ def foo():
     # call rpc in thread
     x = thread2(c, 19)
     yield x                             # print 19
-    print x.get_result()                           # 20
+    print x.result                           # 20
     
+    # Test InProgressCallback destruction cleans up signal connection.
+    ip = kaa.inprogress(sig['one'])
+    assert(len(sig['one']) == 1)
+    del ip
+    gc.collect()
+    assert(len(sig['one']) == 0)
+    print 'InProgressCallback cleanup ok'
+
+    # Test InProgressAny via Signals.any()
+    kaa.OneShotTimer(sig['three'].emit, 'worked').start(0.5)
+    print 'Testing InProgressAny, should return in 0.5s'
+    n, args = yield sig.subset('one', 'three').any()
+    print 'InProgressAny returned:', n, args
+    # Force InProgressCallbacks implicitly created by any() to be deleted.
+    gc.collect()
+    # Verify that they _are_ deleted and detached from the signal.
+    print sig['one']._callbacks
+    assert(len(sig['one']) == 0)
+    assert(n == 1)
+
+    # Test InProgressAll via Signals.all()
+    kaa.OneShotTimer(sig['one'].emit, 'result for sig one').start(0.5)
+    kaa.OneShotTimer(sig['two'].emit, 'result for sig two').start(0.2)
+    print 'Testing InProgressAll, should return in 0.5s'
+    ip = yield sig.subset('one', 'two').all()
+    print 'InProgressAll returned: %s -- %s' % (ip[0].result, ip[1].result)
+
     # normal rpc, we don't care about the answer
     c.rpc('shutdown')
     yield 21
