@@ -22,5 +22,5 @@ NamedThreadCallback(('x', 5), foo, 3)()
 j = NamedThreadCallback('x', foo, 4)()
 NamedThreadCallback('x', foo, 5)()
 NamedThreadCallback('y', foo, 6)()
-j.stop()
+j.abort()
 kaa.main.run()
